@@ -12,6 +12,7 @@ import urllib.request, urllib.parse, urllib.error
 import gi
 gi.require_version("Gtk", "3.0")
 gi.require_version("MateMenu", "2.0")
+gi.require_version("XApp", "1.0")
 from gi.repository import Gtk, Gdk, GdkPixbuf, Gio, GLib, MateMenu, XApp
 
 import plugins.recentHelper as RecentHelper
@@ -173,11 +174,11 @@ class pluginclass(object):
     toButton = (Gtk.TargetEntry.new("text/uri-list", 0, TARGET_TYPE_TEXT),
                 Gtk.TargetEntry.new("text/uri-list", 0, TARGET_TYPE_TEXT))
     TARGET_TYPE_FAV = 81
-    toFav = (Gtk.TargetEntry.new("FAVORITES", Gtk.TargetFlags.SAME_APP, 81),
+    toFav = (Gtk.TargetEntry.new("text/plain", Gtk.TargetFlags.SAME_APP, 81),
              Gtk.TargetEntry.new("text/plain", 0, 100),
              Gtk.TargetEntry.new("text/uri-list", 0, 101))
-    fromFav = (Gtk.TargetEntry.new("FAVORITES", Gtk.TargetFlags.SAME_APP, 81),
-               Gtk.TargetEntry.new("FAVORITES", Gtk.TargetFlags.SAME_APP, 81))
+    fromFav = (Gtk.TargetEntry.new("text/plain", Gtk.TargetFlags.SAME_APP, 81),
+               Gtk.TargetEntry.new("text/plain", Gtk.TargetFlags.SAME_APP, 81))
 
     #@print_timing
     def __init__(self, pearlMenuWin, toggleButton, de):
@@ -1266,7 +1267,7 @@ class pluginclass(object):
         path = os.path.join(home, ".pearllinux/pearlMenu/applications.list")
 
         if os.path.isdir(path):
-            # dir created by a bug in pearl 19.2 beta
+            # dir created by a bug in mint 19.2 beta
             os.system("rm -rf %s" % path)
             return
 
@@ -1431,12 +1432,11 @@ class pluginclass(object):
     def on_drag_data_get(self, widget, context, selection, info, time):
         if info == self.TARGET_TYPE_FAV:
             self.drag_origin = widget.position
-            # FIXME: This fails in python3:
-            selection.set(selection.get_target(), 8, str(widget.position))
+            selection.set_text(str(widget.position), -1)
 
     def on_drag_data_received(self, widget, context, x, y, selection, info, time):
         if info == self.TARGET_TYPE_FAV:
-            self.favoritesReorder(int(selection.get_data()), widget.position)
+            self.favoritesReorder(int(selection.get_data().decode()), widget.position)
 
     # def on_icon_theme_changed(self, theme):
     #     print("on_icon_theme_changed")
