@@ -49,8 +49,8 @@ class pearlMenuPreferences():
 
     def __init__(self):
 
-        self.settings = Gio.Settings("com.pearllinux.pearlmenu")
-        self.places_settings = Gio.Settings("com.pearllinux.pearlmenu.plugins.places")
+        self.settings = Gio.Settings(schema_id="com.pearllinux.pearlmenu")
+        self.places_settings = Gio.Settings(schema_id="com.pearllinux.pearlmenu.plugins.places")
 
         self.builder = Gtk.Builder()
         self.builder.set_translation_domain("pearlmenu")
